@@ -10,7 +10,7 @@ CONFIG = {
         "MLOPS": {
             "TEST_URL": "https://rec-dev.shinsegae.ai/v1",
             "MLOPS_REC_URL": "https://rec-dev.shinsegae.ai/v1",
-            "MLOPS_DATA_URL": "https://data-dev.shinsegae.ai/v1",
+            "MLOPS_DATA_URL": "http://internal-data-dev-v1.shinsegae.ai",
         },
     },
     "STG": {
@@ -22,7 +22,19 @@ CONFIG = {
         "MLOPS": {
             "TEST_URL": "https://rec-stg.shinsegae.ai/v1",
             "MLOPS_REC_URL": "https://rec-stg.shinsegae.ai/v1",
-            "MLOPS_DATA_URL": "https://data-stg.shinsegae.ai/v1",
+            "MLOPS_DATA_URL": "http://internal-data-stg-v1.shinsegae.ai",
+        },
+    },
+    "PRD": {
+        "LOCAL": {
+            "TEST_URL": "https://rec.shinsegae.ai/v1",
+            "MLOPS_REC_URL": "https://rec.shinsegae.ai/v1",
+            "MLOPS_DATA_URL": "https://data.shinsegae.ai/v1",
+        },
+        "MLOPS": {
+            "TEST_URL": "https://rec.shinsegae.ai/v1",
+            "MLOPS_REC_URL": "https://rec.shinsegae.ai/v1",
+            "MLOPS_DATA_URL": "http://internal-data-prd-v1.shinsegae.ai",
         },
     },
 }
