@@ -7,7 +7,7 @@ import cloudpickle
 from botocore.exceptions import ClientError
 from mlops_sdk.config import Config
 from mlops_sdk.mlops_client import MlopsError
-from mlops_sdk.ml.mlops_model import MLOpsModel
+from mlops_sdk.ml import MlopsModel
 
 from pathlib import Path
 import hvac
@@ -47,7 +47,7 @@ class ModelRegistry:
         ```
         """
 
-    def save(self, ml_model: MLOpsModel, force: bool = False, model_artifact: str = None) -> None:
+    def save(self, ml_model: MlopsModel, force: bool = False, model_artifact: str = None) -> None:
         """
         모델 바이너리(model.joblib)와 정보(model.json)를 모델 레지스트리에 등록합니다.
 
